@@ -11,6 +11,7 @@ from requests.exceptions import (
     MissingSchema,
     RequestException,
 )
+from sentry_sdk import capture_exception
 
 from httprunner.schema import RequestData, ResponseData
 from httprunner.schema import SessionData, ReqRespData
@@ -41,14 +42,22 @@ def get_req_resp_record(resp_obj: Response) -> ReqRespData:
 
     # record actual request info
     request_headers = dict(resp_obj.request.headers)
-    request_cookies = dict(resp_obj.request._cookies)
+    request_cookies = resp_obj.request._cookies.get_dict()
+
     request_body = resp_obj.request.body
-    try:
-        request_body = json.loads(request_body)
-    except (json.JSONDecodeError, UnicodeDecodeError):
-        pass
+    if request_body is not None:
+        try:
+            request_body = json.loads(request_body)
+        except json.JSONDecodeError:
+            # str: a=1&b=2
+            pass
+        except UnicodeDecodeError as ex:
+            # bytes/bytearray: request body in protobuf
+            capture_exception(ex)
+        except TypeError as ex:
+            # neither str nor bytes/bytearray, e.g. <MultipartEncoder>
+            capture_exception(ex)
 
-    if request_body:
         request_content_type = lower_dict_keys(request_headers).get("content-type")
         if request_content_type and "multipart/form-data" in request_content_type:
             # upload file type
