@@ -12,45 +12,39 @@ from httprunner.schema import VariablesMapping, Validators, FunctionsMapping
 def get_uniform_comparator(comparator: Text):
     """ convert comparator alias to uniform name
     """
-    if comparator in ["eq", "equals", "==", "is"]:
-        return "equals"
+    if comparator in ["eq", "equals", "equal"]:
+        return "equal"
     elif comparator in ["lt", "less_than"]:
         return "less_than"
-    elif comparator in ["le", "less_than_or_equals"]:
-        return "less_than_or_equals"
+    elif comparator in ["le", "less_or_equals"]:
+        return "less_or_equals"
     elif comparator in ["gt", "greater_than"]:
         return "greater_than"
-    elif comparator in ["ge", "greater_than_or_equals"]:
-        return "greater_than_or_equals"
-    elif comparator in ["ne", "not_equals"]:
-        return "not_equals"
+    elif comparator in ["ge", "greater_or_equals"]:
+        return "greater_or_equals"
+    elif comparator in ["ne", "not_equal"]:
+        return "not_equal"
     elif comparator in ["str_eq", "string_equals"]:
         return "string_equals"
-    elif comparator in ["len_eq", "length_equals", "count_eq"]:
-        return "length_equals"
+    elif comparator in ["len_eq", "length_equal"]:
+        return "length_equal"
     elif comparator in [
         "len_gt",
-        "count_gt",
         "length_greater_than",
-        "count_greater_than",
     ]:
         return "length_greater_than"
     elif comparator in [
         "len_ge",
-        "count_ge",
-        "length_greater_than_or_equals",
-        "count_greater_than_or_equals",
+        "length_greater_or_equals",
     ]:
-        return "length_greater_than_or_equals"
-    elif comparator in ["len_lt", "count_lt", "length_less_than", "count_less_than"]:
+        return "length_greater_or_equals"
+    elif comparator in ["len_lt", "length_less_than"]:
         return "length_less_than"
     elif comparator in [
         "len_le",
-        "count_le",
-        "length_less_than_or_equals",
-        "count_less_than_or_equals",
+        "length_less_or_equals",
     ]:
-        return "length_less_than_or_equals"
+        return "length_less_or_equals"
     else:
         return comparator
 
@@ -62,8 +56,8 @@ def uniform_validator(validator):
         validator (dict): validator maybe in two formats:
 
             format1: this is kept for compatibility with the previous versions.
-                {"check": "status_code", "assert": "eq", "expect": 201}
-                {"check": "$resp_body_success", "assert": "eq", "expect": True}
+                {"check": "status_code", "comparator": "eq", "expect": 201}
+                {"check": "$resp_body_success", "comparator": "eq", "expect": True}
             format2: recommended new version, {assert: [check_item, expected_value]}
                 {'eq': ['status_code', 201]}
                 {'eq': ['$resp_body_success', True]}
@@ -169,11 +163,10 @@ class ResponseObject(object):
                 check_value = parse_data(
                     check_item, variables_mapping, functions_mapping
                 )
+                check_value = parse_string_value(check_value)
             else:
                 check_value = jmespath.search(check_item, self.resp_obj_meta)
 
-            check_value = parse_string_value(check_value)
-
             # comparator
             assert_method = u_validator["assert"]
             assert_func = get_mapping_function(assert_method, functions_mapping)
