@@ -2,9 +2,15 @@ import os
 import time
 import uuid
 from datetime import datetime
-from typing import List, Dict, Text
+from typing import List, Dict, Text, NoReturn
+
+try:
+    import allure
+
+    USE_ALLURE = True
+except ModuleNotFoundError:
+    USE_ALLURE = False
 
-import allure
 from loguru import logger
 
 from httprunner import utils, exceptions
@@ -14,6 +20,7 @@ from httprunner.ext.uploader import prepare_upload_step
 from httprunner.loader import load_project_meta, load_testcase_file
 from httprunner.parser import build_url, parse_data, parse_variables_mapping
 from httprunner.response import ResponseObject
+from httprunner.testcase import Config, Step
 from httprunner.schema import (
     TConfig,
     TStep,
@@ -28,21 +35,37 @@ from httprunner.schema import (
 
 
 class HttpRunner(object):
-    config: TConfig
-    teststeps: List[TStep]
+    config: Config
+    teststeps: List[Step]
 
     success: bool = True  # indicate testcase execution result
+    __config: TConfig
+    __teststeps: List[TStep]
     __project_meta: ProjectMeta = None
     __case_id: Text = ""
     __step_datas: List[StepData] = None
     __session: HttpSession = None
     __session_variables: VariablesMapping = {}
+    __export_variables: VariablesMapping = {}
     # time
     __start_at: float = 0
     __duration: float = 0
     # log
     __log_path: Text = ""
 
+    def __init_tests__(self) -> NoReturn:
+        self.__config = self.config.perform()
+        self.__teststeps = []
+        for step in self.teststeps:
+            self.__teststeps.append(step.perform())
+
+    @property
+    def raw_testcase(self) -> TestCase:
+        if not hasattr(self, "__config"):
+            self.__init_tests__()
+
+        return TestCase(config=self.__config, teststeps=self.__teststeps)
+
     def with_project_meta(self, project_meta: ProjectMeta) -> "HttpRunner":
         self.__project_meta = project_meta
         return self
@@ -59,7 +82,7 @@ class HttpRunner(object):
         self.__session_variables = variables
         return self
 
-    def __run_step_request(self, step: TStep):
+    def __run_step_request(self, step: TStep) -> StepData:
         """run teststep: request"""
         step_data = StepData(name=step.name)
 
@@ -78,7 +101,8 @@ class HttpRunner(object):
         # prepare arguments
         method = parsed_request_dict.pop("method")
         url_path = parsed_request_dict.pop("url")
-        url = build_url(self.config.base_url, url_path)
+        url = build_url(self.__config.base_url, url_path)
+        parsed_request_dict["verify"] = self.__config.verify
         parsed_request_dict["json"] = parsed_request_dict.pop("req_json", {})
 
         # request
@@ -125,6 +149,8 @@ class HttpRunner(object):
         except ValidationFailure:
             self.__session.data.success = False
             log_req_resp_details()
+            # log testcase duration before raise ValidationFailure
+            self.__duration = time.time() - self.__start_at
             raise
         finally:
             # save request & response meta data
@@ -136,7 +162,7 @@ class HttpRunner(object):
 
         return step_data
 
-    def __run_step_testcase(self, step):
+    def __run_step_testcase(self, step: TStep) -> StepData:
         """run teststep: referenced testcase"""
         step_data = StepData(name=step.name)
         step_variables = step.variables
@@ -177,7 +203,7 @@ class HttpRunner(object):
 
         return step_data
 
-    def __run_step(self, step: TStep):
+    def __run_step(self, step: TStep) -> Dict:
         """run teststep, teststep maybe a request or referenced testcase"""
         logger.info(f"run step begin: {step.name} >>>>>>")
 
@@ -194,7 +220,7 @@ class HttpRunner(object):
         logger.info(f"run step end: {step.name} <<<<<<\n")
         return step_data.export
 
-    def __parse_config(self, config: TConfig):
+    def __parse_config(self, config: TConfig) -> NoReturn:
         config.variables.update(self.__session_variables)
         config.variables = parse_variables_mapping(
             config.variables, self.__project_meta.functions
@@ -206,7 +232,7 @@ class HttpRunner(object):
             config.base_url, config.variables, self.__project_meta.functions
         )
 
-    def run_testcase(self, testcase: TestCase):
+    def run_testcase(self, testcase: TestCase) -> "HttpRunner":
         """run specified testcase
 
         Examples:
@@ -214,21 +240,24 @@ class HttpRunner(object):
             >>> HttpRunner().with_project_meta(project_meta).run_testcase(testcase_obj)
 
         """
-        self.config = testcase.config
-        self.teststeps = testcase.teststeps
+        self.__config = testcase.config
+        self.__teststeps = testcase.teststeps
 
         # prepare
-        self.__project_meta = self.__project_meta or load_project_meta(self.config.path)
-        self.__parse_config(self.config)
+        self.__project_meta = self.__project_meta or load_project_meta(
+            self.__config.path
+        )
+        self.__parse_config(self.__config)
         self.__start_at = time.time()
         self.__step_datas: List[StepData] = []
         self.__session = self.__session or HttpSession()
         self.__session_variables = {}
+        self.__export_variables = {}
 
         # run teststeps
-        for step in self.teststeps:
+        for step in self.__teststeps:
             # update with config variables
-            step.variables.update(self.config.variables)
+            step.variables.update(self.__config.variables)
             # update with session variables extracted from pre step
             step.variables.update(self.__session_variables)
             # parse variables
@@ -236,12 +265,20 @@ class HttpRunner(object):
                 step.variables, self.__project_meta.functions
             )
             # run step
-            with allure.step(f"step: {step.name}"):
+            if USE_ALLURE:
+                with allure.step(f"step: {step.name}"):
+                    extract_mapping = self.__run_step(step)
+            else:
                 extract_mapping = self.__run_step(step)
             # save extracted variables to session variables
             self.__session_variables.update(extract_mapping)
 
         self.__duration = time.time() - self.__start_at
+
+        self.__export_variables = self.get_export_variables()
+        if self.__export_variables:
+            logger.info(f"export variables: {self.__export_variables}")
+
         return self
 
     def run_path(self, path: Text) -> "HttpRunner":
@@ -258,15 +295,19 @@ class HttpRunner(object):
             >>> TestCaseRequestWithFunctions().run()
 
         """
-        testcase_obj = TestCase(config=self.config, teststeps=self.teststeps)
+        self.__init_tests__()
+        testcase_obj = TestCase(config=self.__config, teststeps=self.__teststeps)
         return self.run_testcase(testcase_obj)
 
     def get_step_datas(self) -> List[StepData]:
         return self.__step_datas
 
     def get_export_variables(self) -> Dict:
+        if self.__export_variables:
+            return self.__export_variables
+
         export_vars_mapping = {}
-        for var_name in self.config.export:
+        for var_name in self.__config.export:
             if var_name not in self.__session_variables:
                 raise ParamsError(
                     f"failed to export variable {var_name} from session variables {self.__session_variables}"
@@ -281,7 +322,7 @@ class HttpRunner(object):
         start_at_timestamp = self.__start_at
         start_at_iso_format = datetime.utcfromtimestamp(start_at_timestamp).isoformat()
         return TestCaseSummary(
-            name=self.config.name,
+            name=self.__config.name,
             success=self.success,
             case_id=self.__case_id,
             time=TestCaseTime(
@@ -290,39 +331,43 @@ class HttpRunner(object):
                 duration=self.__duration,
             ),
             in_out=TestCaseInOut(
-                vars=self.config.variables, export=self.get_export_variables()
+                vars=self.__config.variables, export=self.get_export_variables()
             ),
             log=self.__log_path,
             step_datas=self.__step_datas,
         )
 
-    def test_start(self):
+    def test_start(self) -> "HttpRunner":
         """main entrance, discovered by pytest"""
+        self.__init_tests__()
+        self.__project_meta = self.__project_meta or load_project_meta(
+            self.__config.path
+        )
         self.__case_id = self.__case_id or str(uuid.uuid4())
         self.__log_path = self.__log_path or os.path.join(
-            "logs", f"{self.__case_id}.run.log"
+            self.__project_meta.PWD, "logs", f"{self.__case_id}.run.log"
         )
         log_handler = logger.add(self.__log_path, level="DEBUG")
 
         # parse config name
-        self.__project_meta = self.__project_meta or load_project_meta(self.config.path)
-        variables = self.config.variables
+        variables = self.__config.variables
         variables.update(self.__session_variables)
-        self.config.name = parse_data(
-            self.config.name, variables, self.__project_meta.functions
+        self.__config.name = parse_data(
+            self.__config.name, variables, self.__project_meta.functions
         )
 
-        # update allure report meta
-        allure.dynamic.title(self.config.name)
-        allure.dynamic.description(f"TestCase ID: {self.__case_id}")
+        if USE_ALLURE:
+            # update allure report meta
+            allure.dynamic.title(self.__config.name)
+            allure.dynamic.description(f"TestCase ID: {self.__case_id}")
 
         logger.info(
-            f"Start to run testcase: {self.config.name}, TestCase ID: {self.__case_id}"
+            f"Start to run testcase: {self.__config.name}, TestCase ID: {self.__case_id}"
         )
 
         try:
             return self.run_testcase(
-                TestCase(config=self.config, teststeps=self.teststeps)
+                TestCase(config=self.__config, teststeps=self.__teststeps)
             )
         finally:
             logger.remove(log_handler)
